[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula A"}},"key":"1D56C"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula B"}},"key":"1D56D"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula C"}},"key":"1D56E"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula D"}},"key":"1D56F"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula E"}},"key":"1D570"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula F"}},"key":"1D571"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula G"}},"key":"1D572"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula H"}},"key":"1D573"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula I"}},"key":"1D574"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula J"}},"key":"1D575"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula K"}},"key":"1D576"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula L"}},"key":"1D577"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula M"}},"key":"1D578"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula N"}},"key":"1D579"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula O"}},"key":"1D57A"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula P"}},"key":"1D57B"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula Q"}},"key":"1D57C"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula R"}},"key":"1D57D"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula S"}},"key":"1D57E"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula T"}},"key":"1D57F"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula U"}},"key":"1D580"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula V"}},"key":"1D581"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula W"}},"key":"1D582"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula X"}},"key":"1D583"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula Y"}},"key":"1D584"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula Z"}},"key":"1D585"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur a"}},"key":"1D586"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur b"}},"key":"1D587"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur c"}},"key":"1D588"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur d"}},"key":"1D589"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur e"}},"key":"1D58A"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur f"}},"key":"1D58B"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur g"}},"key":"1D58C"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur h"}},"key":"1D58D"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur i"}},"key":"1D58E"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur j"}},"key":"1D58F"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur k"}},"key":"1D590"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur l"}},"key":"1D591"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur m"}},"key":"1D592"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur n"}},"key":"1D593"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur o"}},"key":"1D594"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur p"}},"key":"1D595"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur q"}},"key":"1D596"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur r"}},"key":"1D597"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur s"}},"key":"1D598"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur t"}},"key":"1D599"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur u"}},"key":"1D59A"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur v"}},"key":"1D59B"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur w"}},"key":"1D59C"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur x"}},"key":"1D59D"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur y"}},"key":"1D59E"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur z"}},"key":"1D59F"}]
