# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2019-2020 Tiago Tresoldi
# Copyright (c) 2016- Spyder Project Contributors
#
# Licensed under the terms of the BSD 3-clause license
# (see LICENSE.txt in this directory for details)
# -----------------------------------------------------------------------------

"""
DAFSA
-----------

Objects defined in this module were adapted from
`DAFSA <https://github.com/tresoldi/dafsa>`_.
"""

__author__ = 'Tiago Tresoldi'
__email__ = 'tresoldi@shh.mpg.de'
__version__ = '1.0.0'
